#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'tk_paradise/tk_paradise.rb'
# include Tk
# =========================================================================== #
require 'tk'

module Tk

  alias choose_colour chooseColor # === choose_colour

  # ========================================================================= #
  # Provide some "aliases".
  # ========================================================================= #
  Grid = TkGrid
  Font = TkFont
  # ========================================================================= #
  # Button = TkButton
  # Note that the tk-gem already defines Button.
  # ========================================================================= #

  # ========================================================================= #
  # === e
  # ========================================================================= #
  def e(i = '')
    puts i
  end

  # ========================================================================= #
  # === Tk.run
  # ========================================================================= #
  def self.run
    ::Tk.mainloop
  end

  # ========================================================================= #
  # === Tk.root
  # ========================================================================= #
  def self.root(hash = {}, &block)
    root = TkRoot.new { hash }
    if block_given?
      yielded = yield
      if yielded.is_a? Hash
        # =================================================================== #
        # === :geometry
        # =================================================================== #
        if yielded.has_key? :geometry
          root.geometry(yielded[:geometry])
        end
        # =================================================================== #
        # === :title
        # =================================================================== #
        if yielded.has_key? :title
          root.title = yielded[:title]
        end
      end
    end
    return root
  end

  # ========================================================================= #
  # === tk_label
  #
  # The second argument should be the root-widget.
  #
  # Usage example:
  #
  #   tk_label('Message in the Bottom', root) { :on_bottom }
  #
  # ========================================================================= #
  def tk_label(
      text_to_use = '',
      root_widget = nil,
      font        = nil # fontStyle = tkFont.Font(family="Lucida Grande", size=20)
    )
    pack_onto_this_side = 'bottom'
    # ======================================================================= #
    # === Handle blocks next
    # ======================================================================= #
    if block_given?
      yielded = yield
      case yielded # case tag
      # ===================================================================== #
      # === :on_bottom
      # ===================================================================== #
      when :on_bottom
        pack_onto_this_side = 'bottom'
      # ===================================================================== #
      # === :on_right
      # ===================================================================== #
      when :on_right
        pack_onto_this_side = 'right'
      end
    end
    ::TkMessage.new(root_widget) {
      text(text_to_use)
    }.pack('side' => pack_onto_this_side)
  end; alias label tk_label # === label

  # ========================================================================= #
  # === tk_image
  #
  # Usage examples:
  #
  #   - create an empty image of 300x200 pixels:
  #
  #       image = TkPhotoImage.new(height: 200, width: 300)
  #
  #   - create an image from a file:
  #
  #       image = TkPhotoImage.new(file: 'my_image.gif')
  #
  # ========================================================================= #
  def tk_image(
      path_to_the_image,
      extra_arguments = { height: 50 }
    )
    hash = {}
    hash['file'] = path_to_the_image
    hash.merge(extra_arguments)
    return ::TkPhotoImage.new(hash)
  end; alias image tk_image # === image

  # ========================================================================= #
  # === tk_button
  # ========================================================================= #
  # def tk_button
  # end; alias button tk_button # === button

  class Button

    # ======================================================================= #
    # === set_font
    # ======================================================================= #
    def set_font(i)
      self['font'] = i
    end

  end

  class TkLabel

    # ======================================================================= #
    # === set_text
    # ======================================================================= #
    def set_text(i)
      configure(text: i)
    end

  end
    
# create button
# button = Button(gui, text='My Button', bg='#0052cc', fg='#ffffff')
# # apply font to the button label
# button['font'] = myFont

end

# =========================================================================== #
# Next, require some addons - modifications of core-tk classes.
# =========================================================================== #
require 'tk_paradise/tk_classes/root.rb'